library(RFQTL)
genotype <- as.matrix(read.table("genotype.tsv",row.names = 1))
phenotype <- read.table(file = "phenotype.tsv")
strainNames <- phenotype[,1]
phenotype <- phenotype[,2]
sampleInfo <- sapply(strainNames,FUN=function(x){
  which(rownames(genotype)==x)
})
mappingData <- preMap(genotype=genotype,
                      phenotype=phenotype,
                      sampleInfo=sampleInfo,
                      scale=T)
###############################################################################
library(randomForest)
realScores <- rfMapper(mappingData = mappingData,
                       permute = F,
                       nforest = 100,
                       ntree = 150)
###############################################################################
permutedScores <- rfMapper(mappingData = mappingData,
                           permute = T,
                           nforest = 100,
                           ntree = 150,
                           nPermutations=10,
                           file="perm1.RData",
                           nCl=4,
                           clType="SOCK")
###############################################################################
pValues <- pEst(path="permutations_prepared/",
                scores=realScores,
                markersPerIteration = 350,
                printProg = T,
                pCorrection = "fdr")
###############################################################################
pValuesX <- pValues[mappingData$genotype2group]
chrVec <- read.csv("chrVec.tsv")[,1]
QTL_list <- QTLgrouper(pmat = pValuesX,
                       sigThreshold = 0.1,
                       corThreshold = 0.8,
                       distThreshold = 9,
                       genotype = genotype,
                       chrVec = chrVec)
###############################################################################
markerPositions <- read.table("markerPositions.tsv",sep="\t",header=T)
writeQTL(QTLlist = QTL_list,traitNames = "SPNCRNA.1571",markerPositions = markerPositions,path="myResults.qtl")
qtl <- readQTL(path = "myResults.qtl")